==> erpmc-0.1.3.tar.gz: lib/store_management/product/model/filter.dart <==
part of '../../../store_management.dart';

class ProductFilter extends NameFilter<int, ProductModel> {
  final InWhere<int>? typeIds;
  final InWhere<int>? catagoryIds;
  final InWhere<int?>? measureUnitIds;
  final InWhere<int?>? userIds;

  final bool? hasExpireDate;
  const ProductFilter({
    super.ids,
    super.status,
    super.text,
    this.typeIds,
    this.catagoryIds,
    this.measureUnitIds,
    this.userIds,
    this.hasExpireDate,
  });

  @override
  bool textCheck(ProductModel element) =>
      text == null ||
      super.textCheck(element) ||
      text!.check(element.secondName) ||
      text!.check(element.description, contains: true);

  @override
  bool check(ProductModel element) =>
      super.check(element) &&
      (typeIds?.check(element.typeId) ?? true) &&
      (catagoryIds?.check(element.catagoryId) ?? true) &&
      (measureUnitIds?.check(element.measureUnitId) ?? true) &&
      (userIds?.check(element.userId) ?? true) &&
      (hasExpireDate == null || (hasExpireDate == element.hasExpireDate));

  @override
  Map<String, dynamic> toMap() => {
        ...super.toMap(),
        "typeIds": typeIds?.toMap(),
        "catagoryIds": catagoryIds?.toMap(),
        "measureUnitIds": measureUnitIds?.toMap(),
        "userIds": userIds?.toMap(),
        "hasExpireDate": hasExpireDate,
      };

  @override
  ProductFilter copyWith({
    InWhere<int>? ids,
    InWhere<bool>? status,
    LikeWhere? text,
    InWhere<int>? typeIds,
    InWhere<int>? measureUnitIds,
    InWhere<int>? catagoryIds,
    InWhere<int>? userIds,
    bool? hasExpireDate,
  }) =>
      ProductFilter(
        ids: ids ?? this.ids,
        status: status ?? this.status,
        text: text ?? this.text,
        typeIds: typeIds ?? this.typeIds,
        measureUnitIds: measureUnitIds ?? this.measureUnitIds,
        catagoryIds: catagoryIds ?? this.catagoryIds,
        userIds: userIds ?? this.userIds,
        hasExpireDate: hasExpireDate ?? this.hasExpireDate,
      );
}

==> erpmc-0.1.7.tar.gz: lib/store_management/product/model/filter.dart <==
part of '../../../store_management.dart';

class ProductFilter extends NameFilter<int, ProductModel> {
  final InWhere<int>? typeIds;
  final InWhere<int>? catagoryIds;
  final InWhere<int?>? measureUnitIds;
  final InWhere<int>? userIds;

  final bool? hasExpireDate;
  const ProductFilter({
    super.ids,
    super.status,
    super.text,
    this.typeIds,
    this.catagoryIds,
    this.measureUnitIds,
    this.userIds,
    this.hasExpireDate,
  });

  @override
  bool textCheck(ProductModel element) =>
      text == null ||
      super.textCheck(element) ||
      text!.check(element.secondName) ||
      text!.check(element.description, contains: true);

  @override
  bool check(ProductModel element) =>
      super.check(element) &&
      (typeIds?.check(element.typeId) ?? true) &&
      (catagoryIds?.check(element.catagoryId) ?? true) &&
      (measureUnitIds?.check(element.measureUnitId) ?? true) &&
      (userIds?.check(element.userId) ?? true) &&
      (hasExpireDate == null || (hasExpireDate == element.hasExpireDate));

  @override
  Map<String, dynamic> toMap() => {
        ...super.toMap(),
        "typeIds": typeIds?.toMap(),
        "catagoryIds": catagoryIds?.toMap(),
        "measureUnitIds": measureUnitIds?.toMap(),
        "userIds": userIds?.toMap(),
        "hasExpireDate": hasExpireDate,
      };

  @override
  ProductFilter copyWith({
    InWhere<int>? ids,
    InWhere<bool>? status,
    LikeWhere? text,
    InWhere<int>? typeIds,
    InWhere<int>? measureUnitIds,
    InWhere<int>? catagoryIds,
    InWhere<int>? userIds,
    bool? hasExpireDate,
  }) =>
      ProductFilter(
        ids: ids ?? this.ids,
        status: status ?? this.status,
        text: text ?? this.text,
        typeIds: typeIds ?? this.typeIds,
        measureUnitIds: measureUnitIds ?? this.measureUnitIds,
        catagoryIds: catagoryIds ?? this.catagoryIds,
        userIds: userIds ?? this.userIds,
        hasExpireDate: hasExpireDate ?? this.hasExpireDate,
      );
}
